# compare-meshes

[![PyPI version](https://badge.fury.io/py/compare-meshes.svg)](https://badge.fury.io/py/compare-meshes)

Compare meshes and polydata for regression testing.

## Installation

```sh
pip install compare-meshes
```
